@@ -1,7 +1,6 @@
 univglms <-function (y, x, oiko = NULL, logged = FALSE) {
     dm <- dim(x)
     n <- dm[1]
-    x <- as.matrix(x)
     d <- dm[2]
     if (is.null(oiko)) {
         if (length(sort_unique(y)) == 2) {
@@ -12,14 +11,14 @@ univglms <-function (y, x, oiko = NULL, logged = FALSE) {
     }
     if (oiko == "binomial") {
         p <- sum(y)/n
-        ini <- -2 * sum(y * log(p) + (1 - y) * log(1 - p))
+        ini <-  -2 * ( n * p * log(p) + (n - n * p) * log(1 - p) )
         mod <- logistic_only(x, y)
         stat <- ini - mod
         pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = logged)
     }
     else if (oiko == "poisson") {
         m <- sum(y)/n
-        ini <- 2 * sum(y * log(y/m), na.rm = TRUE)
+        ini <- 2 * sum( y * log(y), na.rm = TRUE ) - 2 * n * m * log(m)
         mod <- poisson_only(x, y)
         stat <- ini - mod
         pval <- pchisq(stat, 1, lower.tail = FALSE, log.p = logged)
@@ -29,7 +28,7 @@ univglms <-function (y, x, oiko = NULL, logged = FALSE) {
         if (mn_mx[1] > 0 & mn_mx[2] < 1) {
             y <- log(y/(1 - y))
         }
-        rho <- as.vector(cor(y, x))
+        rho <- as.vector( cor(y, x) )
         sqdof <- sqrt(n - 2)
         stat <- rho * sqdof/sqrt(1 - rho^2)
         if (logged) {
